##########################################
# Random Min/Max Scripts
##########################################
#
# Johann Thiel
# ver 11.25.17
# Functions to implement Newton's
# method.
#
##########################################

##########################################
# Finding a min via random trials
##########################################
# g = function
# x0 = lower x-value bound
# x1 = upper x-value bound
# y0 = lower y-value bound
# y1 = upper y-value bound
# n  = number of iterations
##########################################
def randomMin(g,x0,x1,y0,y1,n):
    x = var('x')
    y = var('y')
    f(x,y) = g(x,y)
    xmin = x0
    ymin = y0
    fmin = f(x0,y0)
    for i in range(n):
        x00 = x0+(x1-x0)*random()
        y00 = y0+(y1-y0)*random()
        if f(x00,y00) < fmin:
            xmin = x00
            ymin = y00
            fmin = f(xmin,ymin)
    return (xmin, ymin, fmin)
##########################################

##########################################
# Finding a max via random trials
##########################################
# g = function
# x0 = lower x-value bound
# x1 = upper x-value bound
# y0 = lower y-value bound
# y1 = upper y-value bound
# n  = number of iterations
##########################################
def randomMax(g,x0,x1,y0,y1,n):
    x = var('x')
    y = var('y')
    f(x,y) = g(x,y)
    xmin = x0
    ymin = y0
    fmin = f(x0,y0)
    for i in range(n):
        x00 = x0+(x1-x0)*random()
        y00 = y0+(y1-y0)*random()
        if f(x00,y00) > fmin:
            xmin = x00
            ymin = y00
            fmin = f(xmin,ymin)
    return (xmin, ymin, fmin)
##########################################